var expect = require('chai').expect,
    decode = require('../lib/decode.js'),
    cutils = require('../lib/cutils.js');

describe('decode - Functional Check', function () {
    it('#.decode(link)', function () {
        expect(decode('link', '</1/2>;pmin=10;pmax=60,</1/2/1>,</1/2/2>')).to.be.eql({ path: '/1/2', attrs: { pmin: 10, pmax: 60 }, resrcList: ['/1/2/1', '/1/2/2'] });
    });

    it('#.decode(tlv)', function () {
        expect(decode('tlv', '/3303', cutils.bufferFrom([0x08, 0x00, 0x0b, 0xe4, 0x16, 0x44, 0x41, 0xf8, 0x00, 0x00, 0xe1, 0x16, 0x45, 0x63, 0x08, 0x01, 0x0b, 0xe4, 0x16, 0x44, 0x42, 0xb2, 0x00, 0x00, 0xe1, 0x16, 0x45, 0x66]))).to.be.eql({ '0': { 'sensorValue': 31, 'units': 'c' }, '1': { 'sensorValue': 89, 'units': 'f' } });
        expect(decode('tlv', '/3303/0', cutils.bufferFrom([0x08, 0x00, 0x0b, 0xe4, 0x16, 0x44, 0x41, 0xf8, 0x00, 0x00, 0xe1, 0x16, 0x45, 0x63]))).to.be.eql({ 'sensorValue': 31, 'units': 'c' });
        expect(decode('tlv', '/3303/0/5700', cutils.bufferFrom([0xe4, 0x16, 0x44, 0x41, 0xf8, 0x00, 0x00]))).to.be.eql(31);
        expect(decode('tlv', '/temperature', cutils.bufferFrom([0x08, 0x00, 0x0b, 0xe4, 0x16, 0x44, 0x41, 0xf8, 0x00, 0x00, 0xe1, 0x16, 0x45, 0x63, 0x08, 0x01, 0x0b, 0xe4, 0x16, 0x44, 0x42, 0xb2, 0x00, 0x00, 0xe1, 0x16, 0x45, 0x66]))).to.be.eql({ '0': { 'sensorValue': 31, 'units': 'c' }, '1': { 'sensorValue': 89, 'units': 'f' } });
        expect(decode('tlv', '/temperature/0', cutils.bufferFrom([0x08, 0x00, 0x0b, 0xe4, 0x16, 0x44, 0x41, 0xf8, 0x00, 0x00, 0xe1, 0x16, 0x45, 0x63]))).to.be.eql({ 'sensorValue': 31, 'units': 'c' });
        expect(decode('tlv', '/3303/0/sensorValue', cutils.bufferFrom([0xe4, 0x16, 0x44, 0x41, 0xf8, 0x00, 0x00]))).to.be.eql(31);
        expect(decode('tlv', '/temperature/0/sensorValue', cutils.bufferFrom([0xe4, 0x16, 0x44, 0x41, 0xf8, 0x00, 0x00]))).to.be.eql(31);
    });

    it('#.decode(json)', function () {
        expect(decode('json', 'x', { e: [{ n: '1/0', sv: 'x' }, { n: '1/1', v: 5 }, { n: '2/0', bv: true }] })).to.be.eql({ 1: {  0: 'x', 1: 5 }, 2: {  0: true }});
        expect(decode('json', 'x/y', { e: [{ n: '0', sv: 'x' }, { n: '1', v: 5 }] })).to.be.eql({ 0: 'x', 1: 5 });
        expect(decode('json', 'x/y/z', { e: [{ n: '', v: 5}]})).to.be.eql(5);
        expect(decode('json', '/temperature/0', cutils.bufferFrom([0x7b, 0x22, 0x62, 0x6e, 0x22, 0x3a, 0x22, 0x2f, 0x33, 0x33, 0x30, 0x33, 0x2f, 0x30, 0x22, 0x2c, 0x22, 0x65, 0x22, 0x3a, 0x5b, 0x7b, 0x22, 0x6e, 0x22, 0x3a, 0x22, 0x35, 0x37, 0x30, 0x30, 0x22, 0x2c, 0x22, 0x76, 0x22, 0x3a, 0x33, 0x31, 0x7d, 0x2c, 0x7b, 0x22, 0x6e, 0x22, 0x3a, 0x22, 0x35, 0x37, 0x30, 0x31, 0x22, 0x2c, 0x22, 0x73, 0x76, 0x22, 0x3a, 0x22, 0x63, 0x22, 0x7d, 0x5d, 0x7d, 0x0d]))).to.be.eql({ sensorValue: 31, units: 'c' });
        expect(decode('json', '/temperature/0', '{"bn":"/3303/0","e":[{"n":"5700","v":31},{"n":"5701","sv":"c"}]}')).to.be.eql({ sensorValue: 31, units: 'c' });
    });
});